@@ -17,10 +17,10 @@
 import gpx as mod_gpx
 import parser as mod_parser
 
-def parse(xml_or_file):
+def parse(xml_or_file, parser='lxml'):
     """ Parse xml (string) or file object. This is just an wrapper for GPXParser.parse() function """
 
-    parser = mod_parser.GPXParser(xml_or_file)
+    parser = mod_parser.GPXParser(xml_or_file, parser=parser)
 
     gpx = parser.parse()
 
