@@ -55,15 +55,6 @@ def to_number(str, default=0):
         return None
     return float(str)
 
-def find_first_node(node, child_node_name):
-    if not node or not child_node_name:
-        return None
-    child_nodes = node.childNodes
-    for child_node in child_nodes:
-        if child_node.nodeName == child_node_name:
-            return child_node
-    return None
-
 # Hash utilities:
 
 def __hash(obj):
@@ -93,5 +84,3 @@ def hash_object(obj, *attributes):
         result = result * 31 + __hash(getattr(obj, attribute))
 	
     return result
-
-
